(self.webpackChunkipywidgetvar=self.webpackChunkipywidgetvar||[]).push([[568],{163:(e,i,d)=>{var t=d(337),o=d(431),n=t.DOMWidgetModel.extend({defaults:o.extend(t.DOMWidgetModel.prototype.defaults(),{_model_name:"IpywidgetVarModel",_view_name:"IpywidgetVarView",_model_module:"ipywidgetvar",_view_module:"ipywidgetvar",_model_module_version:"0.1.2",_view_module_version:"0.1.2",value:"IpywidgetVar!",id:"id1"})}),l=t.DOMWidgetView.extend({render:function(){this.value_changed(),this.id_changed(),this.model.on("change:value",this.value_changed,this),this.model.on("change:id",this.id_changed,this)},value_changed:function(){console.log("set value"),this.el.textContent=this.model.get("value")},id_changed:function(){console.log("set id"),this.el.id=this.model.get("id")}});e.exports={IpywidgetVarModel:n,IpywidgetVarView:l}},568:(e,i,d)=>{e.exports=d(163),e.exports.version=d(147).version},147:e=>{"use strict";e.exports={version:"0.1.2"}}}]);